==> ai_management-1.0.3.tar.gz: ai_management-1.0.3/setup.py <==
import setuptools

# Reads the content of your README.md into a variable to be used in the setup below
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='ai_management',                           # should match the package folder
    packages=['C:\\Users\\51028915\\Documents\\GitHub\\ai_management'], # should match the package folder
    version='1.0.3',                                # important for updates
    license='MIT',                                  # should match your chosen license
    description='This is a toolbox to help AI & ML teams to have a better management of their metrics.',
    long_description=long_description,              # loads your README.md
    long_description_content_type="text/markdown",  # README.md is of type 'markdown'
    author='Leroy Merlin Brazil',
    author_email='chapter_inteligencia_artificia@leroymerlin.com.br',
    url='https://github.com/adeo/aim', 
    project_urls = {                                # Optional
        "Bug Tracker": "https://github.com/adeo/aim/issues"
    },
    install_requires=[
        'pandas', 'numpy', 'scikit-learn', 'google-cloud',
        ],                  # list all packages that your package uses
    keywords=["management", "toolbox", "lmbr", "ai"], #descriptive meta-data
    classifiers=[                                   # https://pypi.org/classifiers
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Documentation',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
    ],
)

==> ai_management-1.0.25.tar.gz: ai_management-1.0.25/setup.py <==
import setuptools

# Reads the content of your README.md into a variable to be used in the setup below
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
    
print(setuptools.find_packages())

setuptools.setup(
    name='ai_management',                           # should match the package folder
    packages=['ai_management'],
    #py_modules=['model_evaluation', 'constants', '__init__'],
    package_data={
        # 'examples': ['usage_examples.ipynb'], 
        'ai_management': ['config.yaml'],
    },
    install_requires=[
        'pandas>=1.0.4', 
        'numpy>=1.20.0', 
        'scikit-learn>=1.0.0', 
        'google-cloud-bigquery>=2.34.4',
        ],                  # list all packages that your package uses
    #packages=['C:\\Users\\51028915\\Documents\\GitHub\\ai_management'], # should match the package folder
    version='1.0.25',                                # important for updates
    license='MIT',                                  # should match your chosen license
    description='This is a toolbox to help AI & ML teams to have a better management of their metrics.',
    long_description=long_description,              # loads your README.md
    long_description_content_type="text/markdown",  # README.md is of type 'markdown'
    author='Leroy Merlin Brazil',
    author_email='chapter_inteligencia_artificia@leroymerlin.com.br',
    url='https://github.com/adeo/aim', 
    project_urls = {                                # Optional
        "Bug Tracker": "https://github.com/adeo/aim/issues"
    },
    
    keywords=["management", "toolbox", "lmbr", "ai"], #descriptive meta-data
    classifiers=[                                   # https://pypi.org/classifiers
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Documentation',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
    ],
)
